Index: branches/2.8.x/CHANGELOG
===================================================================
--- branches/2.8.x/CHANGELOG	(revision 1295)
+++ branches/2.8.x/CHANGELOG	(revision 1296)
@@ -12,6 +12,8 @@
 
 ------------------------------------- 2.8.1 -------------------------------------
 19-Feb-2010 Dietmar Woellbrink (Luisehahne)
+!	update headerinfo in module droplets
+19-Feb-2010 Dietmar Woellbrink (Luisehahne)
 !	Beginning with Ticket #901 
 +	add siteadd.png to backend themes
 !	change icon add child page
Index: branches/2.8.x/wb/admin/interface/version.php
===================================================================
--- branches/2.8.x/wb/admin/interface/version.php	(revision 1295)
+++ branches/2.8.x/wb/admin/interface/version.php	(revision 1296)
@@ -52,6 +52,6 @@
 
 // check if defined to avoid errors during installation (redirect to admin panel fails if PHP error/warnings are enabled)
 if(!defined('VERSION')) define('VERSION', '2.8.x');
-if(!defined('REVISION')) define('REVISION', '1295');
+if(!defined('REVISION')) define('REVISION', '1296');
 
 ?>
\ No newline at end of file
Index: branches/2.8.x/wb/modules/droplets/info.php
===================================================================
--- branches/2.8.x/wb/modules/droplets/info.php	(revision 1295)
+++ branches/2.8.x/wb/modules/droplets/info.php	(revision 1296)
@@ -1,16 +1,22 @@
 <?php
+/**
+ *
+ * @category        module
+ * @package         droplet
+ * @author          Ruud Eisinga (Ruud) John (PCWacht)
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.4.9 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+ */
 
-// $Id$
-
-/*
-*	@version	1.0
-*	@author		Ruud Eisinga (Ruud) John (PCWacht)
-*	@date		June 2009
-*
-*	droplets are small codeblocks that are called from anywhere in the template. 
-* 	To call a droplet just use [[dropletname]]. optional parameters for a droplet can be used like [[dropletname?parameter=value&parameter2=value]]
-*/
-
 $module_directory = 'droplets';
 $module_name = 'Droplets';
 $module_function = 'tool';

Property changes on: branches/2.8.x/wb/modules/droplets/info.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/modules/droplets/droplets.php
===================================================================
--- branches/2.8.x/wb/modules/droplets/droplets.php	(revision 1295)
+++ branches/2.8.x/wb/modules/droplets/droplets.php	(revision 1296)
@@ -1,17 +1,31 @@
 <?php
+/**
+ *
+ * @category        module
+ * @package         droplet
+ * @author          Ruud Eisinga (Ruud) John (PCWacht)
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.4.9 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+ */
 
-// $Id$
-
 /*
-*	@version	1.0.2
-*	@author		Ruud Eisinga (Ruud) John (PCWacht)
-*	@date		June 2009
-*
-*	droplets are small codeblocks that are called from anywhere in the template. 
-* 	To call a droplet just use [[dropletname]]. optional parameters for a droplet can be used like [[dropletname?parameter=value&parameter2=value]]\
-*
-*   1.0.2, bugfix. Reused the evalDroplet function so the extracted parameters will be only available within the scope of the eval and cleared when ready.
-*/
+ *	@version	1.0.2
+ *	@date		June 2009
+ *
+ *	droplets are small codeblocks that are called from anywhere in the template.
+ * 	To call a droplet just use [[dropletname]]. optional parameters for a droplet can be used like [[dropletname?parameter=value&parameter2=value]]\
+ *
+ *  1.0.2, bugfix. Reused the evalDroplet function so the extracted parameters will be only available within the scope of the eval and cleared when ready.
+ */
 
 function evalDroplets ($wb_page_data) {
 	global $database;

Property changes on: branches/2.8.x/wb/modules/droplets/droplets.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/modules/droplets/install.php
===================================================================
--- branches/2.8.x/wb/modules/droplets/install.php	(revision 1295)
+++ branches/2.8.x/wb/modules/droplets/install.php	(revision 1296)
@@ -1,90 +1,96 @@
-<?php
-
-// $Id$
-
-/*
-*	@version	1.0
-*	@author		Ruud Eisinga (Ruud) John (PCWacht)
-*	@date		June 2009
-*
-*	droplets are small codeblocks that are called from anywhere in the template. 
-* 	To call a droplet just use [[dropletname]]. optional parameters for a droplet can be used like [[dropletname?parameter=value&parameter2=value]]
-*/
-
-// prevent this file from being accessed directly
-if(!defined('WB_PATH')) die(header('Location: ../../index.php'));
-
-global $admin;
-
-$table = TABLE_PREFIX .'mod_droplets';
-$database->query("DROP TABLE IF EXISTS `$table`");
-
-$database->query("CREATE TABLE `$table` (
-	`id` INT NOT NULL auto_increment,
-	`name` VARCHAR(32) NOT NULL,
-	`code` LONGTEXT NOT NULL ,
-	`description` TEXT NOT NULL,
-	`modified_when` INT NOT NULL default '0',
-	`modified_by` INT NOT NULL default '0',
-	`active` INT NOT NULL default '0',
-	`admin_edit` INT NOT NULL default '0',
-	`admin_view` INT NOT NULL default '0',
-	`show_wysiwyg` INT NOT NULL default '0',
-	`comments` TEXT NOT NULL,
-	PRIMARY KEY ( `id` )
-	)"
-);
-
-//add all droplets from the droplet subdirectory
-$folder=opendir(WB_PATH.'/modules/droplets/example/.'); 
-$names = array();
-while ($file = readdir($folder)) {
-	$ext=strtolower(substr($file,-4));
-	if ($ext==".php"){
-		if ($file<>"index.php" ) {
-			$names[count($names)] = $file; 
-		}
-	}
-}
-closedir($folder);
-
-foreach ($names as $dropfile) {
-	$droplet = addslashes(getDropletCodeFromFile($dropfile));
-	if ($droplet != "") {
-		$description = "Example Droplet";
-		$comments = "Example Droplet";
-		$cArray = explode("\n",$droplet);
-		if (substr($cArray[0],0,3) == "//:") {
-			$description = trim(substr($cArray[0],3));
-			array_shift ( $cArray );
-		}
-		if (substr($cArray[0],0,3) == "//:") {
-			$comments = trim(substr($cArray[0],3));
-			array_shift ( $cArray );
-		}
-		$droplet = implode ( "\n", $cArray );
-		$name = substr($dropfile,0,-4);
-		$modified_when = time();
-		$modified_by = method_exists($admin, 'get_user_id') ? $admin->get_user_id() : 1;
-		$database->query("INSERT INTO `$table`  
-			(name, code, description, comments, active, modified_when, modified_by) 
-			VALUES 
-			('$name', '$droplet', '$description', '$comments', '1', '$modified_when', '$modified_by')");
-		
-		// do not output anything if this script is called during fresh installation
-		if (method_exists($admin, 'get_user_id')) echo "Droplet import: $name<br/>";
-	}  
-}
-
-function getDropletCodeFromFile ( $dropletfile ) {
-	$data = "";
-	$filename = WB_PATH."/modules/droplets/example/".$dropletfile;
-	if (file_exists($filename)) {
-		$filehandle = fopen ($filename, "r");
-		$data = fread ($filehandle, filesize ($filename));
-		fclose($filehandle);
-		// unlink($filename); doesnt work in unix
-	}	
-	return $data;
-}
+<?php
+/**
+ *
+ * @category        module
+ * @package         droplet
+ * @author          Ruud Eisinga (Ruud) John (PCWacht)
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.4.9 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+ */
+
+// prevent this file from being accessed directly
+if(!defined('WB_PATH')) die(header('Location: ../../index.php'));
+
+global $admin;
+
+$table = TABLE_PREFIX .'mod_droplets';
+$database->query("DROP TABLE IF EXISTS `$table`");
+
+$database->query("CREATE TABLE `$table` (
+	`id` INT NOT NULL auto_increment,
+	`name` VARCHAR(32) NOT NULL,
+	`code` LONGTEXT NOT NULL ,
+	`description` TEXT NOT NULL,
+	`modified_when` INT NOT NULL default '0',
+	`modified_by` INT NOT NULL default '0',
+	`active` INT NOT NULL default '0',
+	`admin_edit` INT NOT NULL default '0',
+	`admin_view` INT NOT NULL default '0',
+	`show_wysiwyg` INT NOT NULL default '0',
+	`comments` TEXT NOT NULL,
+	PRIMARY KEY ( `id` )
+	)"
+);
+
+//add all droplets from the droplet subdirectory
+$folder=opendir(WB_PATH.'/modules/droplets/example/.'); 
+$names = array();
+while ($file = readdir($folder)) {
+	$ext=strtolower(substr($file,-4));
+	if ($ext==".php"){
+		if ($file<>"index.php" ) {
+			$names[count($names)] = $file; 
+		}
+	}
+}
+closedir($folder);
+
+foreach ($names as $dropfile) {
+	$droplet = addslashes(getDropletCodeFromFile($dropfile));
+	if ($droplet != "") {
+		$description = "Example Droplet";
+		$comments = "Example Droplet";
+		$cArray = explode("\n",$droplet);
+		if (substr($cArray[0],0,3) == "//:") {
+			$description = trim(substr($cArray[0],3));
+			array_shift ( $cArray );
+		}
+		if (substr($cArray[0],0,3) == "//:") {
+			$comments = trim(substr($cArray[0],3));
+			array_shift ( $cArray );
+		}
+		$droplet = implode ( "\n", $cArray );
+		$name = substr($dropfile,0,-4);
+		$modified_when = time();
+		$modified_by = method_exists($admin, 'get_user_id') ? $admin->get_user_id() : 1;
+		$database->query("INSERT INTO `$table`  
+			(name, code, description, comments, active, modified_when, modified_by) 
+			VALUES 
+			('$name', '$droplet', '$description', '$comments', '1', '$modified_when', '$modified_by')");
+		
+		// do not output anything if this script is called during fresh installation
+		if (method_exists($admin, 'get_user_id')) echo "Droplet import: $name<br/>";
+	}  
+}
+
+function getDropletCodeFromFile ( $dropletfile ) {
+	$data = "";
+	$filename = WB_PATH."/modules/droplets/example/".$dropletfile;
+	if (file_exists($filename)) {
+		$filehandle = fopen ($filename, "r");
+		$data = fread ($filehandle, filesize ($filename));
+		fclose($filehandle);
+		// unlink($filename); doesnt work in unix
+	}	
+	return $data;
+}
 ?>
\ No newline at end of file

Property changes on: branches/2.8.x/wb/modules/droplets/install.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/modules/droplets/index.php
===================================================================
--- branches/2.8.x/wb/modules/droplets/index.php	(revision 1295)
+++ branches/2.8.x/wb/modules/droplets/index.php	(revision 1296)
@@ -1,28 +1,22 @@
-<?php
-
-// $Id$
-
-/*
-
- Website Baker Project <http://www.websitebaker.org/>
- Copyright (C) 2004-2009, Ryan Djurovich
-
- Website Baker is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- Website Baker is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with Website Baker; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-*/
-
-header('Location: ../index.php');
-
+<?php
+/**
+ *
+ * @category        module
+ * @package         droplet
+ * @author          Ruud Eisinga (Ruud) John (PCWacht)
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.4.9 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+ */
+
+header('Location: ../index.php');
+
 ?>
\ No newline at end of file

Property changes on: branches/2.8.x/wb/modules/droplets/index.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/modules/droplets/uninstall.php
===================================================================
--- branches/2.8.x/wb/modules/droplets/uninstall.php	(revision 1295)
+++ branches/2.8.x/wb/modules/droplets/uninstall.php	(revision 1296)
@@ -1,20 +1,26 @@
-<?php
-
-// $Id$
-
-/*
-*	@version	1.0
-*	@author		Ruud Eisinga (Ruud) John (PCWacht)
-*	@date		June 2009
-*
-*	droplets are small codeblocks that are called from anywhere in the template. 
-* 	To call a droplet just use [[dropletname]]. optional parameters for a droplet can be used like [[dropletname?parameter=value&parameter2=value]]
-*/
-
-// prevent this file from being accessed directly
-if(!defined('WB_PATH')) die(header('Location: ../index.php'));
-
-$table = TABLE_PREFIX .'mod_droplets';
-$database->query("DROP TABLE IF EXISTS `$table`");
-
+<?php
+/**
+ *
+ * @category        module
+ * @package         droplet
+ * @author          Ruud Eisinga (Ruud) John (PCWacht)
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.4.9 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+ */
+
+// prevent this file from being accessed directly
+if(!defined('WB_PATH')) die(header('Location: ../index.php'));
+
+$table = TABLE_PREFIX .'mod_droplets';
+$database->query("DROP TABLE IF EXISTS `$table`");
+
 ?>
\ No newline at end of file

Property changes on: branches/2.8.x/wb/modules/droplets/uninstall.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/modules/droplets/tool.php
===================================================================
--- branches/2.8.x/wb/modules/droplets/tool.php	(revision 1295)
+++ branches/2.8.x/wb/modules/droplets/tool.php	(revision 1296)
@@ -1,16 +1,22 @@
 <?php
+/**
+ *
+ * @category        module
+ * @package         droplet
+ * @author          Ruud Eisinga (Ruud) John (PCWacht)
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.4.9 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+ */
 
-// $Id$
-
-/*
-*	@version	1.0
-*	@author		Ruud Eisinga (Ruud) John (PCWacht)
-*	@date		June 2009
-*
-*	droplets are small codeblocks that are called from anywhere in the template. 
-* 	To call a droplet just use [[dropletname]]. optional parameters for a droplet can be used like [[dropletname?parameter=value&parameter2=value]]
-*/
-
 // Direct access prevention
 defined('WB_PATH') OR die(header('Location: ../index.php'));
 

Property changes on: branches/2.8.x/wb/modules/droplets/tool.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/modules/droplets/modify_droplet.php
===================================================================
--- branches/2.8.x/wb/modules/droplets/modify_droplet.php	(revision 1295)
+++ branches/2.8.x/wb/modules/droplets/modify_droplet.php	(revision 1296)
@@ -1,16 +1,22 @@
 <?php
+/**
+ *
+ * @category        module
+ * @package         droplet
+ * @author          Ruud Eisinga (Ruud) John (PCWacht)
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.4.9 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+ */
 
-// $Id$
-
-/*
-*	@version	1.0
-*	@author		Ruud Eisinga (Ruud) John (PCWacht)
-*	@date		June 2009
-*
-*	droplets are small codeblocks that are called from anywhere in the template. 
-* 	To call a droplet just use [[dropletname]]. optional parameters for a droplet can be used like [[dropletname?parameter=value&parameter2=value]]
-*/
-
 require('../../config.php');
 
 // Get id

Property changes on: branches/2.8.x/wb/modules/droplets/modify_droplet.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/modules/droplets/add_droplet.php
===================================================================
--- branches/2.8.x/wb/modules/droplets/add_droplet.php	(revision 1295)
+++ branches/2.8.x/wb/modules/droplets/add_droplet.php	(revision 1296)
@@ -1,46 +1,52 @@
-<?php
-
-// $Id$
-
-/*
-*	@version	1.0
-*	@author		Ruud Eisinga (Ruud) John (PCWacht)
-*	@date		June 2009
-*
-*	droplets are small codeblocks that are called from anywhere in the template. 
-* 	To call a droplet just use [[dropletname]]. optional parameters for a droplet can be used like [[dropletname?parameter=value&parameter2=value]]
-*/
-
-require('../../config.php');
-
-require_once(WB_PATH.'/framework/class.admin.php');
-require_once(WB_PATH.'/framework/functions.php');
-$admin = new admin('admintools','admintools',false,false);
-if($admin->get_permission('admintools') == true) {
-	
-	$admintool_link = ADMIN_URL .'/admintools/index.php';
-	$module_edit_link = ADMIN_URL .'/admintools/tool.php?tool=droplets';
-	$admin = new admin('admintools', 'admintools');
-
-	$modified_when = time();
-	$modified_by = $admin->get_user_id();
-
-	// Insert new row into database
-	$database->query("INSERT INTO ".TABLE_PREFIX."mod_droplets (active,modified_when,modified_by) VALUES ('1','$modified_when','$modified_by' )");
-
-	// Get the id
-	$droplet_id = $database->get_one("SELECT LAST_INSERT_ID()");
-
-	// Say that a new record has been added, then redirect to modify page
-	if($database->is_error()) {
-		$admin->print_error($database->get_error(), $module_edit_link);
-	} else {
-		$admin->print_success($TEXT['SUCCESS'], WB_URL.'/modules/droplets/modify_droplet.php?droplet_id='.$droplet_id);
-	}
-
-	// Print admin footer
-	$admin->print_footer();
-} else {
-	die(header('Location: ../../index.php'));
-} 
+<?php
+/**
+ *
+ * @category        module
+ * @package         droplet
+ * @author          Ruud Eisinga (Ruud) John (PCWacht)
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.4.9 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+ */
+
+require('../../config.php');
+
+require_once(WB_PATH.'/framework/class.admin.php');
+require_once(WB_PATH.'/framework/functions.php');
+$admin = new admin('admintools','admintools',false,false);
+if($admin->get_permission('admintools') == true) {
+	
+	$admintool_link = ADMIN_URL .'/admintools/index.php';
+	$module_edit_link = ADMIN_URL .'/admintools/tool.php?tool=droplets';
+	$admin = new admin('admintools', 'admintools');
+
+	$modified_when = time();
+	$modified_by = $admin->get_user_id();
+
+	// Insert new row into database
+	$database->query("INSERT INTO ".TABLE_PREFIX."mod_droplets (active,modified_when,modified_by) VALUES ('1','$modified_when','$modified_by' )");
+
+	// Get the id
+	$droplet_id = $database->get_one("SELECT LAST_INSERT_ID()");
+
+	// Say that a new record has been added, then redirect to modify page
+	if($database->is_error()) {
+		$admin->print_error($database->get_error(), $module_edit_link);
+	} else {
+		$admin->print_success($TEXT['SUCCESS'], WB_URL.'/modules/droplets/modify_droplet.php?droplet_id='.$droplet_id);
+	}
+
+	// Print admin footer
+	$admin->print_footer();
+} else {
+	die(header('Location: ../../index.php'));
+} 
 ?>
\ No newline at end of file

Property changes on: branches/2.8.x/wb/modules/droplets/add_droplet.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/modules/droplets/backup_droplets.php
===================================================================
--- branches/2.8.x/wb/modules/droplets/backup_droplets.php	(revision 1295)
+++ branches/2.8.x/wb/modules/droplets/backup_droplets.php	(revision 1296)
@@ -1,14 +1,22 @@
 <?php
+/**
+ *
+ * @category        module
+ * @package         droplet
+ * @author          Ruud Eisinga (Ruud) John (PCWacht)
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.4.9 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+ */
 
-// $Id$
-
-/*
-*	@version	1.0
-*	@author		Ruud Eisinga (Ruud) John (PCWacht)
-*	@date		June 2009
-*
-*/
-
 // tool_edit.php
 require_once('../../config.php');
 require_once(WB_PATH.'/framework/class.admin.php');

Property changes on: branches/2.8.x/wb/modules/droplets/backup_droplets.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/modules/droplets/save_droplet.php
===================================================================
--- branches/2.8.x/wb/modules/droplets/save_droplet.php	(revision 1295)
+++ branches/2.8.x/wb/modules/droplets/save_droplet.php	(revision 1296)
@@ -1,16 +1,22 @@
 <?php
+/**
+ *
+ * @category        module
+ * @package         droplet
+ * @author          Ruud Eisinga (Ruud) John (PCWacht)
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.4.9 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+ */
 
-// $Id$
-
-/*
-*	@version	1.0
-*	@author		Ruud Eisinga (Ruud) John (PCWacht)
-*	@date		June 2009
-*
-*	droplets are small codeblocks that are called from anywhere in the template. 
-* 	To call a droplet just use [[dropletname]]. optional parameters for a droplet can be used like [[dropletname?parameter=value&parameter2=value]]
-*/
-
 require('../../config.php');
 
 // Get id

Property changes on: branches/2.8.x/wb/modules/droplets/save_droplet.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/modules/droplets/upgrade.php
===================================================================
--- branches/2.8.x/wb/modules/droplets/upgrade.php	(revision 1295)
+++ branches/2.8.x/wb/modules/droplets/upgrade.php	(revision 1296)
@@ -1,17 +1,22 @@
 <?php
+/**
+ *
+ * @category        module
+ * @package         droplet
+ * @author          Ruud Eisinga (Ruud) John (PCWacht)
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.4.9 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+ */
 
-// $Id$
-
-/*
-*	@version	1.0
-*	@author		Ruud Eisinga (Ruud) John (PCWacht)
-*	@date		June 2009
-*
-*
-*	droplets are small codeblocks that are called from anywhere in the template. 
-* 	To call a droplet just use [[dropletname]]. optional parameters for a droplet can be used like [[dropletname?parameter=value&parameter2=value]]
-*/
-
 if(!defined('WB_PATH')) die(header('Location: ../../index.php'));
 
 $table = TABLE_PREFIX .'mod_droplets';

Property changes on: branches/2.8.x/wb/modules/droplets/upgrade.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property

Index: branches/2.8.x/wb/modules/droplets/delete_droplet.php
===================================================================
--- branches/2.8.x/wb/modules/droplets/delete_droplet.php	(revision 1295)
+++ branches/2.8.x/wb/modules/droplets/delete_droplet.php	(revision 1296)
@@ -1,51 +1,57 @@
-<?php
-
-// $Id$
-
-/*
-*	@version	1.0
-*	@author		Ruud Eisinga (Ruud) John (PCWacht)
-*	@date		June 2009
-*
-*	droplets are small codeblocks that are called from anywhere in the template. 
-* 	To call a droplet just use [[dropletname]]. optional parameters for a droplet can be used like [[dropletname?parameter=value&parameter2=value]]
-*/
-
-require('../../config.php');
-
-// Get id
-if(!isset($_GET['droplet_id']) OR !is_numeric($_GET['droplet_id'])) {
-	header("Location: ".ADMIN_URL."/pages/index.php");
-} else {
-	$droplet_id = $_GET['droplet_id'];
-}
-
-// Include WB admin wrapper script
-require_once(WB_PATH.'/framework/class.admin.php');
-require_once(WB_PATH.'/framework/functions.php');
-
-// check website baker platform (with WB 2.7, Admin-Tools were moved out of settings dialogue)
-if(file_exists(ADMIN_PATH .'/admintools/tool.php')) {
-	$admintool_link = ADMIN_URL .'/admintools/index.php';
-	$module_edit_link = ADMIN_URL .'/admintools/tool.php?tool=droplets';
-	$admin = new admin('admintools', 'admintools');
-} else {
-	$admintool_link = ADMIN_URL .'/settings/index.php?advanced=yes#administration_tools"';
-	$module_edit_link = ADMIN_URL .'/settings/tool.php?tool=droplets';
-	$admin = new admin('Settings', 'settings_advanced');
-}
-
-// Delete droplet
-$database->query("DELETE FROM ".TABLE_PREFIX."mod_droplets WHERE id = '$droplet_id' LIMIT 1");
-
-// Check if there is a db error, otherwise say successful
-if($database->is_error()) {
-	$admin->print_error($database->get_error(), WB_URL.'/modules/droplets/modify_droplet.php?droplet_id='.$droplet_id);
-} else {
-    $admin->print_success($TEXT['SUCCESS'], $module_edit_link);
-}
-
-// Print admin footer
-$admin->print_footer();
-
+<?php
+/**
+ *
+ * @category        module
+ * @package         droplet
+ * @author          Ruud Eisinga (Ruud) John (PCWacht)
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.4.9 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+ */
+
+require('../../config.php');
+
+// Get id
+if(!isset($_GET['droplet_id']) OR !is_numeric($_GET['droplet_id'])) {
+	header("Location: ".ADMIN_URL."/pages/index.php");
+} else {
+	$droplet_id = $_GET['droplet_id'];
+}
+
+// Include WB admin wrapper script
+require_once(WB_PATH.'/framework/class.admin.php');
+require_once(WB_PATH.'/framework/functions.php');
+
+// check website baker platform (with WB 2.7, Admin-Tools were moved out of settings dialogue)
+if(file_exists(ADMIN_PATH .'/admintools/tool.php')) {
+	$admintool_link = ADMIN_URL .'/admintools/index.php';
+	$module_edit_link = ADMIN_URL .'/admintools/tool.php?tool=droplets';
+	$admin = new admin('admintools', 'admintools');
+} else {
+	$admintool_link = ADMIN_URL .'/settings/index.php?advanced=yes#administration_tools"';
+	$module_edit_link = ADMIN_URL .'/settings/tool.php?tool=droplets';
+	$admin = new admin('Settings', 'settings_advanced');
+}
+
+// Delete droplet
+$database->query("DELETE FROM ".TABLE_PREFIX."mod_droplets WHERE id = '$droplet_id' LIMIT 1");
+
+// Check if there is a db error, otherwise say successful
+if($database->is_error()) {
+	$admin->print_error($database->get_error(), WB_URL.'/modules/droplets/modify_droplet.php?droplet_id='.$droplet_id);
+} else {
+    $admin->print_success($TEXT['SUCCESS'], $module_edit_link);
+}
+
+// Print admin footer
+$admin->print_footer();
+
 ?>
\ No newline at end of file

Property changes on: branches/2.8.x/wb/modules/droplets/delete_droplet.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property